@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: contravariant
-version: 0.1.2
-id: contravariant-0.1.2-63dbce92591eeda9d33710d2fa60b756
+version: 0.2.0.2
+id: contravariant-0.2.0.2-81baf5bc59727b7a0ef0352dbc950025
 
 license: BSD3
 copyright: Copyright (C) 2007-2011 Edward A. Kmett
@@ -9,6 +9,7 @@ maintainer: Edward A. Kmett <ekmett@gmail.com>
 stability: provisional
 homepage: http://github.com/ekmett/contravariant/
 package-url:
+synopsis: Haskell 98 contravariant functors
 description: Haskell 98 contravariant functors
 category: Control, Data
 author: Edward A. Kmett
@@ -17,20 +18,21 @@ exposed: True
 exposed-modules: Data.Functor.Contravariant
                  Data.Functor.Contravariant.Compose
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/contravariant-0.1.2
-library-dirs: /usr/local/lib/ghc/contravariant-0.1.2
-hs-libraries: HScontravariant-0.1.2
+trusted: False
+import-dirs: /usr/local/lib/ghc/contravariant-0.2.0.2
+library-dirs: /usr/local/lib/ghc/contravariant-0.2.0.2
+hs-libraries: HScontravariant-0.2.0.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         transformers-0.2.2.0-4bbbfde1fb5c4eb17cdb1963dda698f3
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-contravariant-0.1.2/html/contravariant.haddock
-haddock-html: /usr/local/share/doc/hs-contravariant-0.1.2/html
+haddock-interfaces: /usr/local/share/doc/hs-contravariant-0.2.0.2/html/contravariant.haddock
+haddock-html: /usr/local/share/doc/hs-contravariant-0.2.0.2/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
